@@ -380,10 +380,10 @@ static PetscErrorCode PCSetUp_GASM(PC pc)
 
     /* Now the subdomains are defined.  Determine their global and max local numbers, if necessary. */
     if (osm->nmax == PETSC_DETERMINE) {
-      PetscMPIInt inwork, outwork;
+      PetscInt inwork, outwork;
       /* determine global number of subdomains and the max number of local subdomains */
       inwork = osm->n;
-      PetscCall(MPIU_Allreduce(&inwork, &outwork, 1, MPI_INT, MPI_MAX, PetscObjectComm((PetscObject)pc)));
+      PetscCallMPI(MPIU_Allreduce(&inwork, &outwork, 1, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)pc)));
       osm->nmax = outwork;
     }
     if (osm->N == PETSC_DETERMINE) {
@@ -419,13 +419,13 @@ static PetscErrorCode PCSetUp_GASM(PC pc)
       PetscCall(ISRestoreIndices(osm->ois[i], &oidxi));
       on += oni;
     }
-    PetscCall(ISCreateGeneral(((PetscObject)(pc))->comm, on, oidx, PETSC_OWN_POINTER, &gois));
+    PetscCall(ISCreateGeneral(((PetscObject)pc)->comm, on, oidx, PETSC_OWN_POINTER, &gois));
     nTotalInnerIndices = 0;
     for (i = 0; i < osm->n; i++) {
       PetscCall(ISGetLocalSize(osm->iis[i], &nInnerIndices));
       nTotalInnerIndices += nInnerIndices;
     }
-    PetscCall(VecCreateMPI(((PetscObject)(pc))->comm, nTotalInnerIndices, PETSC_DETERMINE, &x));
+    PetscCall(VecCreateMPI(((PetscObject)pc)->comm, nTotalInnerIndices, PETSC_DETERMINE, &x));
     PetscCall(VecDuplicate(x, &y));
 
     PetscCall(VecCreateMPI(PetscObjectComm((PetscObject)pc), on, PETSC_DECIDE, &osm->gx));
@@ -863,7 +863,7 @@ static PetscErrorCode PCDestroy_GASM(PC pc)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode PCSetFromOptions_GASM(PC pc, PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode PCSetFromOptions_GASM(PC pc, PetscOptionItems PetscOptionsObject)
 {
   PC_GASM   *osm = (PC_GASM *)pc->data;
   PetscInt   blocks, ovl;
@@ -965,7 +965,7 @@ static PetscErrorCode PCGASMSetSubdomains_GASM(PC pc, PetscInt n, IS iis[], IS o
   if (PetscDefined(USE_DEBUG)) {
     PetscInt        j, rstart, rend, *covered, lsize;
     const PetscInt *indices;
-    /* check if the inner indices cover and only cover the local portion of the preconditioning matrix */
+    /* check if the inner indices cover and only cover the local portion of the matrix */
     PetscCall(MatGetOwnershipRange(pc->pmat, &rstart, &rend));
     PetscCall(PetscCalloc1(rend - rstart, &covered));
     /* check if the current MPI process owns indices from others */
@@ -1042,9 +1042,9 @@ static PetscErrorCode PCGASMGetSubKSP_GASM(PC pc, PetscInt *n, PetscInt *first,
   PetscFunctionReturn(PETSC_SUCCESS);
 } /* PCGASMGetSubKSP_GASM() */
 
-/*@C
-  PCGASMSetSubdomains - Sets the subdomains for this MPI rank
-  for the additive Schwarz preconditioner with multiple MPI ranks per subdomain, `PCGASM`
+/*@
+  PCGASMSetSubdomains - Sets the subdomains for this MPI process
+  for the additive Schwarz preconditioner with multiple MPI processes per subdomain, `PCGASM`
 
   Collective
 
@@ -1603,9 +1603,6 @@ PetscErrorCode PCGASMDestroySubdomains(PetscInt n, IS *iis[], IS *ois[])
   Note:
   Use `PCGASMDestroySubdomains()` to free the index sets and the arrays
 
-  Fortran Notes:
-  The `IS` must be declared as an array of length long enough to hold `Nsub` entries
-
 .seealso: [](ch_ksp), `PCGASM`, `PCGASMSetSubdomains()`, `PCGASMGetSubKSP()`, `PCGASMSetOverlap()`, `PCASMCreateSubdomains2D()`,
           `PCGASMDestroySubdomains()`
 @*/
