@@ -52,17 +52,46 @@ PETSC_INTERN PetscErrorCode PCGetDefaultType_Private(PC pc, const char *type[])
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/* do not log solves, setup and applications of preconditioners while constructing preconditioners; perhaps they should be logged separately from the regular solves */
+PETSC_EXTERN PetscLogEvent KSP_Solve, KSP_SetUp;
+
+static PetscErrorCode PCLogEventsDeactivatePush(void)
+{
+  PetscFunctionBegin;
+  PetscCall(KSPInitializePackage());
+  PetscCall(PetscLogEventDeactivatePush(KSP_Solve));
+  PetscCall(PetscLogEventDeactivatePush(KSP_SetUp));
+  PetscCall(PetscLogEventDeactivatePush(PC_Apply));
+  PetscCall(PetscLogEventDeactivatePush(PC_SetUp));
+  PetscCall(PetscLogEventDeactivatePush(PC_SetUpOnBlocks));
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+static PetscErrorCode PCLogEventsDeactivatePop(void)
+{
+  PetscFunctionBegin;
+  PetscCall(KSPInitializePackage());
+  PetscCall(PetscLogEventDeactivatePop(KSP_Solve));
+  PetscCall(PetscLogEventDeactivatePop(KSP_SetUp));
+  PetscCall(PetscLogEventDeactivatePop(PC_Apply));
+  PetscCall(PetscLogEventDeactivatePop(PC_SetUp));
+  PetscCall(PetscLogEventDeactivatePop(PC_SetUpOnBlocks));
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
 /*@
-  PCReset - Resets a `PC` context to the pcsetupcalled = 0 state and removes any allocated `Vec`s and `Mat`s
+  PCReset - Resets a `PC` context to the state it was in before `PCSetUp()` was called, and removes any allocated `Vec` and `Mat` from its data structure
 
   Collective
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Level: developer
 
-  Note:
+  Notes:
+  Any options set, including those set with `KSPSetFromOptions()` remain.
+
   This allows a `PC` to be reused for a different sized linear system but using the same options that have been previously set in `pc`
 
 .seealso: [](ch_ksp), `PC`, `PCCreate()`, `PCSetUp()`
@@ -81,13 +110,13 @@ PetscErrorCode PCReset(PC pc)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
   PCDestroy - Destroys `PC` context that was created with `PCCreate()`.
 
   Collective
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Level: developer
 
@@ -113,14 +142,14 @@ PetscErrorCode PCDestroy(PC *pc)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
   PCGetDiagonalScale - Indicates if the preconditioner applies an additional left and right
   scaling as needed by certain time-stepping codes.
 
   Logically Collective
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Output Parameter:
 . flag - `PETSC_TRUE` if it applies the scaling
@@ -155,7 +184,7 @@ PetscErrorCode PCGetDiagonalScale(PC pc, PetscBool *flag)
   Logically Collective
 
   Input Parameters:
-+ pc - the preconditioner context
++ pc - the `PC` preconditioner context
 - s  - scaling vector
 
   Level: intermediate
@@ -197,7 +226,7 @@ PetscErrorCode PCSetDiagonalScale(PC pc, Vec s)
   Logically Collective
 
   Input Parameters:
-+ pc  - the preconditioner context
++ pc  - the `PC` preconditioner context
 . in  - input vector
 - out - scaled vector (maybe the same as in)
 
@@ -217,7 +246,7 @@ PetscErrorCode PCSetDiagonalScale(PC pc, Vec s)
 
   If diagonal scaling is turned off and `in` is not `out` then `in` is copied to `out`
 
-.seealso: [](ch_ksp), `PCCreate()`, `PCSetUp()`, `PCSetDiagonalScale()`, `PCDiagonalScaleRight()`, `PCDiagonalScale()`
+.seealso: [](ch_ksp), `PCCreate()`, `PCSetUp()`, `PCSetDiagonalScale()`, `PCDiagonalScaleRight()`, `MatDiagonalScale()`
 @*/
 PetscErrorCode PCDiagonalScaleLeft(PC pc, Vec in, Vec out)
 {
@@ -239,7 +268,7 @@ PetscErrorCode PCDiagonalScaleLeft(PC pc, Vec in, Vec out)
   Logically Collective
 
   Input Parameters:
-+ pc  - the preconditioner context
++ pc  - the `PC` preconditioner context
 . in  - input vector
 - out - scaled vector (maybe the same as in)
 
@@ -259,7 +288,7 @@ PetscErrorCode PCDiagonalScaleLeft(PC pc, Vec in, Vec out)
 
   If diagonal scaling is turned off and `in` is not `out` then `in` is copied to `out`
 
-.seealso: [](ch_ksp), `PCCreate()`, `PCSetUp()`, `PCDiagonalScaleLeft()`, `PCSetDiagonalScale()`, `PCDiagonalScale()`
+.seealso: [](ch_ksp), `PCCreate()`, `PCSetUp()`, `PCDiagonalScaleLeft()`, `PCSetDiagonalScale()`, `MatDiagonalScale()`
 @*/
 PetscErrorCode PCDiagonalScaleRight(PC pc, Vec in, Vec out)
 {
@@ -283,7 +312,7 @@ PetscErrorCode PCDiagonalScaleRight(PC pc, Vec in, Vec out)
   Logically Collective
 
   Input Parameters:
-+ pc  - the preconditioner context
++ pc  - the `PC` preconditioner context
 - flg - `PETSC_TRUE` to use the Amat, `PETSC_FALSE` to use the Pmat (default is false)
 
   Options Database Key:
@@ -295,7 +324,7 @@ PetscErrorCode PCDiagonalScaleRight(PC pc, Vec in, Vec out)
   For the common case in which the linear system matrix and the matrix used to construct the
   preconditioner are identical, this routine has no affect.
 
-.seealso: [](ch_ksp), `PC`, `PCGetUseAmat()`, `PCBJACOBI`, `PGMG`, `PCFIELDSPLIT`, `PCCOMPOSITE`,
+.seealso: [](ch_ksp), `PC`, `PCGetUseAmat()`, `PCBJACOBI`, `PCMG`, `PCFIELDSPLIT`, `PCCOMPOSITE`,
           `KSPSetOperators()`, `PCSetOperators()`
 @*/
 PetscErrorCode PCSetUseAmat(PC pc, PetscBool flg)
@@ -343,7 +372,7 @@ PetscErrorCode PCSetErrorIfFailure(PC pc, PetscBool flg)
   Logically Collective
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Output Parameter:
 . flg - `PETSC_TRUE` to use the Amat, `PETSC_FALSE` to use the Pmat (default is false)
@@ -354,7 +383,7 @@ PetscErrorCode PCSetErrorIfFailure(PC pc, PetscBool flg)
   For the common case in which the linear system matrix and the matrix used to construct the
   preconditioner are identical, this routine is does nothing.
 
-.seealso: [](ch_ksp), `PC`, `PCSetUseAmat()`, `PCBJACOBI`, `PGMG`, `PCFIELDSPLIT`, `PCCOMPOSITE`
+.seealso: [](ch_ksp), `PC`, `PCSetUseAmat()`, `PCBJACOBI`, `PCMG`, `PCFIELDSPLIT`, `PCCOMPOSITE`
 @*/
 PetscErrorCode PCGetUseAmat(PC pc, PetscBool *flg)
 {
@@ -419,15 +448,19 @@ PetscErrorCode PCGetKSPNestLevel(PC pc, PetscInt *level)
 . comm - MPI communicator
 
   Output Parameter:
-. newpc - location to put the preconditioner context
+. newpc - location to put the `PC` preconditioner context
 
   Level: developer
 
-  Note:
-  The default preconditioner for sparse matrices is `PCILU` or `PCICC` with 0 fill on one process and block Jacobi (`PCBJACOBI`) with `PCILU` or `PCICC`
+  Notes:
+  This is rarely called directly by users since `KSP` manages the `PC` objects it uses. Use `KSPGetPC()` to access the `PC` used by a `KSP`.
+
+  Use `PCSetType()` or `PCSetFromOptions()` with the option `-pc_type pctype` to set the `PCType` for this `PC`
+
+  The default preconditioner type `PCType` for sparse matrices is `PCILU` or `PCICC` with 0 fill on one process and block Jacobi (`PCBJACOBI`) with `PCILU` or `PCICC`
   in parallel. For dense matrices it is always `PCNONE`.
 
-.seealso: [](ch_ksp), `PC`, `PCSetUp()`, `PCApply()`, `PCDestroy()`
+.seealso: [](ch_ksp), `PC`, `PCType`, `PCSetType`, `PCSetUp()`, `PCApply()`, `PCDestroy()`, `KSP`, `KSPGetPC()`
 @*/
 PetscErrorCode PCCreate(MPI_Comm comm, PC *newpc)
 {
@@ -435,11 +468,9 @@ PetscErrorCode PCCreate(MPI_Comm comm, PC *newpc)
 
   PetscFunctionBegin;
   PetscAssertPointer(newpc, 2);
-  *newpc = NULL;
   PetscCall(PCInitializePackage());
 
   PetscCall(PetscHeaderCreate(pc, PC_CLASSID, "PC", "Preconditioner", "PC", comm, PCDestroy, PCView));
-
   pc->mat                  = NULL;
   pc->pmat                 = NULL;
   pc->setupcalled          = 0;
@@ -462,7 +493,7 @@ PetscErrorCode PCCreate(MPI_Comm comm, PC *newpc)
   Collective
 
   Input Parameters:
-+ pc - the preconditioner context
++ pc - the `PC` preconditioner context
 - x  - input vector
 
   Output Parameter:
@@ -507,7 +538,7 @@ PetscErrorCode PCApply(PC pc, Vec x, Vec y)
   Collective
 
   Input Parameters:
-+ pc - the preconditioner context
++ pc - the `PC` preconditioner context
 - X  - block of input vectors
 
   Output Parameter:
@@ -569,7 +600,7 @@ PetscErrorCode PCMatApply(PC pc, Mat X, Mat Y)
   Collective
 
   Input Parameters:
-+ pc - the preconditioner context
++ pc - the `PC` preconditioner context
 - x  - input vector
 
   Output Parameter:
@@ -606,7 +637,7 @@ PetscErrorCode PCApplySymmetricLeft(PC pc, Vec x, Vec y)
   Collective
 
   Input Parameters:
-+ pc - the preconditioner context
++ pc - the `PC` preconditioner context
 - x  - input vector
 
   Output Parameter:
@@ -643,7 +674,7 @@ PetscErrorCode PCApplySymmetricRight(PC pc, Vec x, Vec y)
   Collective
 
   Input Parameters:
-+ pc - the preconditioner context
++ pc - the `PC` preconditioner context
 - x  - input vector
 
   Output Parameter:
@@ -683,7 +714,7 @@ PetscErrorCode PCApplyTranspose(PC pc, Vec x, Vec y)
   Collective
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Output Parameter:
 . flg - `PETSC_TRUE` if a transpose operation is defined
@@ -708,7 +739,7 @@ PetscErrorCode PCApplyTransposeExists(PC pc, PetscBool *flg)
   Collective
 
   Input Parameters:
-+ pc   - the preconditioner context
++ pc   - the `PC` preconditioner context
 . side - indicates the preconditioner side, one of `PC_LEFT`, `PC_RIGHT`, or `PC_SYMMETRIC`
 . x    - input vector
 - work - work vector
@@ -789,7 +820,7 @@ PetscErrorCode PCApplyBAorAB(PC pc, PCSide side, Vec x, Vec y, Vec work)
   Collective
 
   Input Parameters:
-+ pc   - the preconditioner context
++ pc   - the `PC` preconditioner context
 . side - indicates the preconditioner side, one of `PC_LEFT`, `PC_RIGHT`, or `PC_SYMMETRIC`
 . x    - input vector
 - work - work vector
@@ -868,7 +899,7 @@ PetscErrorCode PCApplyRichardsonExists(PC pc, PetscBool *exists)
   Collective
 
   Input Parameters:
-+ pc        - the preconditioner context
++ pc        - the `PC` preconditioner context
 . b         - the right-hand side
 . w         - one work vector
 . rtol      - relative decrease in residual norm convergence criteria
@@ -912,8 +943,8 @@ PetscErrorCode PCApplyRichardson(PC pc, Vec b, Vec y, Vec w, PetscReal rtol, Pet
   Logically Collective
 
   Input Parameters:
-+ pc     - the preconditioner context
-- reason - the reason it failedx
++ pc     - the `PC` preconditioner context
+- reason - the reason it failed
 
   Level: advanced
 
@@ -930,39 +961,10 @@ PetscErrorCode PCSetFailedReason(PC pc, PCFailedReason reason)
 /*@
   PCGetFailedReason - Gets the reason a `PCSetUp()` failed or `PC_NOERROR` if it did not fail
 
-  Logically Collective
-
-  Input Parameter:
-. pc - the preconditioner context
-
-  Output Parameter:
-. reason - the reason it failed
-
-  Level: advanced
-
-  Note:
-  This is the maximum over reason over all ranks in the PC communicator. It is only valid after
-  a call `KSPCheckDot()` or  `KSPCheckNorm()` inside a `KSPSolve()` or `PCReduceFailedReason()`.
-  It is not valid immediately after a `PCSetUp()` or `PCApply()`, then use `PCGetFailedReasonRank()`
-
-.seealso: [](ch_ksp), `PC`, ``PCCreate()`, `PCApply()`, `PCDestroy()`, `PCGetFailedReasonRank()`, `PCSetFailedReason()`
-@*/
-PetscErrorCode PCGetFailedReason(PC pc, PCFailedReason *reason)
-{
-  PetscFunctionBegin;
-  PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
-  if (pc->setupcalled < 0) *reason = (PCFailedReason)pc->setupcalled;
-  else *reason = pc->failedreason;
-  PetscFunctionReturn(PETSC_SUCCESS);
-}
-
-/*@
-  PCGetFailedReasonRank - Gets the reason a `PCSetUp()` failed or `PC_NOERROR` if it did not fail on this MPI rank
-
   Not Collective
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Output Parameter:
 . reason - the reason it failed
@@ -970,11 +972,13 @@ PetscErrorCode PCGetFailedReason(PC pc, PCFailedReason *reason)
   Level: advanced
 
   Note:
-  Different processes may have different reasons or no reason, see `PCGetFailedReason()`
+  After a call to `KSPCheckDot()` or  `KSPCheckNorm()` inside a `KSPSolve()` or a call to `PCReduceFailedReason()`
+  this is the maximum reason over all MPI processes in the `PC` communicator and hence logically collective.
+  Otherwise it returns the local value.
 
-.seealso: [](ch_ksp), `PC`, `PCCreate()`, `PCApply()`, `PCDestroy()`, `PCGetFailedReason()`, `PCSetFailedReason()`, `PCReduceFailedReason()`
+.seealso: [](ch_ksp), `PC`, `PCCreate()`, `PCApply()`, `PCDestroy()`, `PCSetFailedReason()`, `PCFailedReason`
 @*/
-PetscErrorCode PCGetFailedReasonRank(PC pc, PCFailedReason *reason)
+PetscErrorCode PCGetFailedReason(PC pc, PCFailedReason *reason)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
@@ -989,7 +993,7 @@ PetscErrorCode PCGetFailedReasonRank(PC pc, PCFailedReason *reason)
   Collective
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Level: advanced
 
@@ -997,7 +1001,7 @@ PetscErrorCode PCGetFailedReasonRank(PC pc, PCFailedReason *reason)
   Different MPI processes may have different reasons or no reason, see `PCGetFailedReason()`. This routine
   makes them have a common value (failure if any MPI process had a failure).
 
-.seealso: [](ch_ksp), `PC`, `PCCreate()`, `PCApply()`, `PCDestroy()`, `PCGetFailedReason()`, `PCSetFailedReason()`
+.seealso: [](ch_ksp), `PC`, `PCCreate()`, `PCApply()`, `PCDestroy()`, `PCGetFailedReason()`, `PCSetFailedReason()`, `PCFailedReason`
 @*/
 PetscErrorCode PCReduceFailedReason(PC pc)
 {
@@ -1006,30 +1010,36 @@ PetscErrorCode PCReduceFailedReason(PC pc)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   buf = (PetscInt)pc->failedreason;
-  PetscCall(MPIU_Allreduce(MPI_IN_PLACE, &buf, 1, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)pc)));
+  PetscCallMPI(MPIU_Allreduce(MPI_IN_PLACE, &buf, 1, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)pc)));
   pc->failedreason = (PCFailedReason)buf;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*  Next line needed to deactivate KSP_Solve logging */
-#include <petsc/private/kspimpl.h>
-
 /*
       a setupcall of 0 indicates never setup,
                      1 indicates has been previously setup
                     -1 indicates a PCSetUp() was attempted and failed
 */
 /*@
-  PCSetUp - Prepares for the use of a preconditioner.
+  PCSetUp - Prepares for the use of a preconditioner. Performs all the one-time operations needed before the preconditioner
+  can be used with `PCApply()`
 
   Collective
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Level: developer
 
-.seealso: [](ch_ksp), `PC`, `PCCreate()`, `PCApply()`, `PCDestroy()`
+  Notes:
+  For example, for `PCLU` this will compute the factorization.
+
+  This is called automatically by `KSPSetUp()` or `PCApply()` so rarely needs to be called directly.
+
+  For nested preconditioners, such as `PCFIELDSPLIT` or `PCBJACOBI` this may not finish the construction of the preconditioner
+  on the inner levels, the routine `PCSetUpOnBlocks()` may compute more of the preconditioner in those situations.
+
+.seealso: [](ch_ksp), `PC`, `PCCreate()`, `PCApply()`, `PCDestroy()`, `KSPSetUp()`, `PCSetUpOnBlocks()`
 @*/
 PetscErrorCode PCSetUp(PC pc)
 {
@@ -1072,13 +1082,9 @@ PetscErrorCode PCSetUp(PC pc)
   PetscCall(MatSetErrorIfFailure(pc->mat, pc->erroriffailure));
   PetscCall(PetscLogEventBegin(PC_SetUp, pc, 0, 0, 0));
   if (pc->ops->setup) {
-    /* do not log solves and applications of preconditioners while constructing preconditioners; perhaps they should be logged separately from the regular solves */
-    PetscCall(KSPInitializePackage());
-    PetscCall(PetscLogEventDeactivatePush(KSP_Solve));
-    PetscCall(PetscLogEventDeactivatePush(PC_Apply));
+    PetscCall(PCLogEventsDeactivatePush());
     PetscUseTypeMethod(pc, setup);
-    PetscCall(PetscLogEventDeactivatePop(KSP_Solve));
-    PetscCall(PetscLogEventDeactivatePop(PC_Apply));
+    PetscCall(PCLogEventsDeactivatePop());
   }
   PetscCall(PetscLogEventEnd(PC_SetUp, pc, 0, 0, 0));
   if (!pc->setupcalled) pc->setupcalled = 1;
@@ -1087,29 +1093,34 @@ PetscErrorCode PCSetUp(PC pc)
 
 /*@
   PCSetUpOnBlocks - Sets up the preconditioner for each block in
-  the block Jacobi, block Gauss-Seidel, and overlapping Schwarz
-  methods.
+  the block Jacobi, overlapping Schwarz, and fieldsplit methods.
 
   Collective
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Level: developer
 
-  Note:
-  For nested preconditioners such as `PCBJACOBI` `PCSetUp()` is not called on each sub-`KSP` when `PCSetUp()` is
+  Notes:
+  For nested preconditioners such as `PCBJACOBI`, `PCSetUp()` is not called on each sub-`KSP` when `PCSetUp()` is
   called on the outer `PC`, this routine ensures it is called.
 
+  It calls `PCSetUp()` if not yet called.
+
 .seealso: [](ch_ksp), `PC`, `PCSetUp()`, `PCCreate()`, `PCApply()`, `PCDestroy()`
 @*/
 PetscErrorCode PCSetUpOnBlocks(PC pc)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
+  if (!pc->setupcalled) PetscCall(PCSetUp(pc)); /* "if" to prevent -info extra prints */
   if (!pc->ops->setuponblocks) PetscFunctionReturn(PETSC_SUCCESS);
+  PetscCall(MatSetErrorIfFailure(pc->pmat, pc->erroriffailure));
   PetscCall(PetscLogEventBegin(PC_SetUpOnBlocks, pc, 0, 0, 0));
+  PetscCall(PCLogEventsDeactivatePush());
   PetscUseTypeMethod(pc, setuponblocks);
+  PetscCall(PCLogEventsDeactivatePop());
   PetscCall(PetscLogEventEnd(PC_SetUpOnBlocks, pc, 0, 0, 0));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -1121,12 +1132,12 @@ PetscErrorCode PCSetUpOnBlocks(PC pc)
   Logically Collective
 
   Input Parameters:
-+ pc   - the preconditioner context
++ pc   - the `PC` preconditioner context
 . func - routine for modifying the submatrices
 - ctx  - optional user-defined context (may be `NULL`)
 
   Calling sequence of `func`:
-+ pc     - the preconditioner context
++ pc     - the `PC` preconditioner context
 . nsub   - number of index sets
 . row    - an array of index sets that contain the global row numbers
          that comprise each local submatrix
@@ -1139,7 +1150,7 @@ PetscErrorCode PCSetUpOnBlocks(PC pc)
   Level: advanced
 
   Notes:
-  The basic submatrices are extracted from the preconditioner matrix as
+  The basic submatrices are extracted from the matrix used to construct the preconditioner as
   usual; the user can then alter these (for example, to set different boundary
   conditions for each submatrix) before they are used for the local solves.
 
@@ -1168,7 +1179,7 @@ PetscErrorCode PCSetModifySubMatrices(PC pc, PetscErrorCode (*func)(PC pc, Petsc
   Collective
 
   Input Parameters:
-+ pc     - the preconditioner context
++ pc     - the `PC` preconditioner context
 . nsub   - the number of local submatrices
 . row    - an array of index sets that contain the global row numbers
          that comprise each local submatrix
@@ -1208,7 +1219,7 @@ PetscErrorCode PCModifySubMatrices(PC pc, PetscInt nsub, const IS row[], const I
   Logically Collective
 
   Input Parameters:
-+ pc   - the preconditioner context
++ pc   - the `PC` preconditioner context
 . Amat - the matrix that defines the linear system
 - Pmat - the matrix to be used in constructing the preconditioner, usually the same as Amat.
 
@@ -1265,12 +1276,12 @@ PetscErrorCode PCSetOperators(PC pc, Mat Amat, Mat Pmat)
 }
 
 /*@
-  PCSetReusePreconditioner - reuse the current preconditioner even if the operator in the preconditioner has changed.
+  PCSetReusePreconditioner - reuse the current preconditioner even if the operator in the preconditioner `PC` has changed.
 
   Logically Collective
 
   Input Parameters:
-+ pc   - the preconditioner context
++ pc   - the `PC` preconditioner context
 - flag - `PETSC_TRUE` do not compute a new preconditioner, `PETSC_FALSE` do compute a new preconditioner
 
   Level: intermediate
@@ -1296,7 +1307,7 @@ PetscErrorCode PCSetReusePreconditioner(PC pc, PetscBool flag)
   Not Collective
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Output Parameter:
 . flag - `PETSC_TRUE` do not compute a new preconditioner, `PETSC_FALSE` do compute a new preconditioner
@@ -1316,12 +1327,12 @@ PetscErrorCode PCGetReusePreconditioner(PC pc, PetscBool *flag)
 
 /*@
   PCGetOperators - Gets the matrix associated with the linear system and
-  possibly a different one associated with the preconditioner.
+  possibly a different one which is used to construct the preconditioner.
 
   Not Collective, though parallel `Mat`s are returned if `pc` is parallel
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Output Parameters:
 + Amat - the matrix defining the linear system
@@ -1412,14 +1423,14 @@ PetscErrorCode PCGetOperators(PC pc, Mat *Amat, Mat *Pmat)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
   PCGetOperatorsSet - Determines if the matrix associated with the linear system and
   possibly a different one associated with the preconditioner have been set in the `PC`.
 
   Not Collective, though the results on all processes should be the same
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Output Parameters:
 + mat  - the matrix associated with the linear system was set
@@ -1446,7 +1457,7 @@ PetscErrorCode PCGetOperatorsSet(PC pc, PetscBool *mat, PetscBool *pmat)
   Not Collective though `mat` is parallel if `pc` is parallel
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Output Parameters:
 . mat - the factored matrix
@@ -1468,14 +1479,14 @@ PetscErrorCode PCFactorGetMatrix(PC pc, Mat *mat)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
   PCSetOptionsPrefix - Sets the prefix used for searching for all
   `PC` options in the database.
 
   Logically Collective
 
   Input Parameters:
-+ pc     - the preconditioner context
++ pc     - the `PC` preconditioner context
 - prefix - the prefix string to prepend to all `PC` option requests
 
   Note:
@@ -1495,14 +1506,14 @@ PetscErrorCode PCSetOptionsPrefix(PC pc, const char prefix[])
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
   PCAppendOptionsPrefix - Appends to the prefix used for searching for all
   `PC` options in the database.
 
   Logically Collective
 
   Input Parameters:
-+ pc     - the preconditioner context
++ pc     - the `PC` preconditioner context
 - prefix - the prefix string to prepend to all `PC` option requests
 
   Note:
@@ -1522,24 +1533,20 @@ PetscErrorCode PCAppendOptionsPrefix(PC pc, const char prefix[])
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
   PCGetOptionsPrefix - Gets the prefix used for searching for all
   PC options in the database.
 
   Not Collective
 
   Input Parameter:
-. pc - the preconditioner context
+. pc - the `PC` preconditioner context
 
   Output Parameter:
 . prefix - pointer to the prefix string used, is returned
 
   Level: advanced
 
-  Fortran Note:
-  The user should pass in a string `prefix` of
-  sufficient length to hold the prefix.
-
 .seealso: [](ch_ksp), `PC`, `PCSetFromOptions`, `PCSetOptionsPrefix()`, `PCAppendOptionsPrefix()`
 @*/
 PetscErrorCode PCGetOptionsPrefix(PC pc, const char *prefix[])
@@ -1567,31 +1574,27 @@ PETSC_INTERN PetscErrorCode PCPreSolveChangeRHS(PC pc, PetscBool *change)
 }
 
 /*@
-  PCPreSolve - Optional pre-solve phase, intended for any
-  preconditioner-specific actions that must be performed before
-  the iterative solve itself.
+  PCPreSolve - Optional pre-solve phase, intended for any preconditioner-specific actions that must be performed before
+  the iterative solve itself. Used in conjunction with `PCPostSolve()`
 
   Collective
 
   Input Parameters:
-+ pc  - the preconditioner context
++ pc  - the `PC` preconditioner context
 - ksp - the Krylov subspace context
 
   Level: developer
 
-  Example Usage:
-.vb
-    PCPreSolve(pc,ksp);
-    KSPSolve(ksp,b,x);
-    PCPostSolve(pc,ksp);
-.ve
-
   Notes:
-  The pre-solve phase is distinct from the `PCSetUp()` phase.
-
   `KSPSolve()` calls this directly, so is rarely called by the user.
 
-.seealso: [](ch_ksp), `PC`, `PCPostSolve()`
+  Certain preconditioners, such as the `PCType` of `PCEISENSTAT`, change the formulation of the linear system to be solved iteratively.
+  This function performs that transformation. `PCPostSolve()` then transforms the system back to its original form after the solve.
+  `PCPostSolve()` also transforms the resulting solution of the transformed system to the solution of the original problem.
+
+  `KSPSetPreSolve()` and `KSPSetPostSolve()` provide an alternative way to provide such transformations.
+
+.seealso: [](ch_ksp), `PC`, `PCPostSolve()`, `KSP`, `PCSetPreSolve()`, `KSPSetPreSolve()`, `KSPSetPostSolve()`
 @*/
 PetscErrorCode PCPreSolve(PC pc, KSP ksp)
 {
@@ -1645,8 +1648,8 @@ PetscErrorCode PCSetPreSolve(PC pc, PetscErrorCode (*presolve)(PC pc, KSP ksp))
   Collective
 
   Input Parameters:
-+ pc  - the preconditioner context
-- ksp - the Krylov subspace context
++ pc  - the `PC` preconditioner context
+- ksp - the `KSP` Krylov subspace context
 
   Example Usage:
 .vb
@@ -1660,7 +1663,7 @@ PetscErrorCode PCSetPreSolve(PC pc, PetscErrorCode (*presolve)(PC pc, KSP ksp))
   Note:
   `KSPSolve()` calls this routine directly, so it is rarely called by the user.
 
-.seealso: [](ch_ksp), `PC`, `PCSetPostSolve()`, `PCSetPresolve()`, `PCPreSolve()`, `KSPSolve()`
+.seealso: [](ch_ksp), `PC`, `PCSetPreSolve()`, `KSPSetPostSolve()`, `KSPSetPreSolve()`, `PCPreSolve()`, `KSPSolve()`
 @*/
 PetscErrorCode PCPostSolve(PC pc, KSP ksp)
 {
@@ -1676,7 +1679,7 @@ PetscErrorCode PCPostSolve(PC pc, KSP ksp)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
   PCLoad - Loads a `PC` that has been stored in binary  with `PCView()`.
 
   Collective
@@ -1684,14 +1687,14 @@ PetscErrorCode PCPostSolve(PC pc, KSP ksp)
   Input Parameters:
 + newdm  - the newly loaded `PC`, this needs to have been created with `PCCreate()` or
            some related function before a call to `PCLoad()`.
-- viewer - binary file viewer, obtained from `PetscViewerBinaryOpen()`
+- viewer - binary file viewer `PETSCVIEWERBINARY`, obtained from `PetscViewerBinaryOpen()`
 
   Level: intermediate
 
   Note:
   The type is determined by the data in the file, any `PCType` set into the `PC` before this call is ignored.
 
-.seealso: [](ch_ksp), `PC`, `PetscViewerBinaryOpen()`, `PCView()`, `MatLoad()`, `VecLoad()`
+.seealso: [](ch_ksp), `PC`, `PetscViewerBinaryOpen()`, `PCView()`, `MatLoad()`, `VecLoad()`, `PETSCVIEWERBINARY`
 @*/
 PetscErrorCode PCLoad(PC newdm, PetscViewer viewer)
 {
@@ -1718,17 +1721,17 @@ PetscErrorCode PCLoad(PC newdm, PetscViewer viewer)
   #include <petscviewersaws.h>
 #endif
 
-/*@C
-  PCViewFromOptions - View from the `PC` based on options in the options database
+/*@
+  PCViewFromOptions - View (print or provide information about) the `PC`, based on options in the options database
 
   Collective
 
   Input Parameters:
 + A    - the `PC` context
 . obj  - Optional object that provides the options prefix
-- name - command line option
+- name - command line option name
 
-  Level: intermediate
+  Level: developer
 
 .seealso: [](ch_ksp), `PC`, `PCView`, `PetscObjectViewFromOptions()`, `PCCreate()`
 @*/
@@ -1740,16 +1743,16 @@ PetscErrorCode PCViewFromOptions(PC A, PetscObject obj, const char name[])
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
   PCView - Prints information about the `PC`
 
   Collective
 
   Input Parameters:
-+ pc     - the `PC` context
-- viewer - optional visualization context
++ pc     - the `PC` preconditioner context
+- viewer - optional `PetscViewer` visualization context
 
-  Level: developer
+  Level: intermediate
 
   Notes:
   The available visualization contexts include
@@ -1762,7 +1765,7 @@ PetscErrorCode PCViewFromOptions(PC A, PetscObject obj, const char name[])
   The user can open an alternative visualization contexts with
   `PetscViewerASCIIOpen()` (output to a specified file).
 
-.seealso: [](ch_ksp), `PC`, `PetscViewer`, `KSPView()`, `PetscViewerASCIIOpen()`
+.seealso: [](ch_ksp), `PC`, `PetscViewer`, `PetscViewerType`, `KSPView()`, `PetscViewerASCIIOpen()`
 @*/
 PetscErrorCode PCView(PC pc, PetscViewer viewer)
 {
@@ -1871,13 +1874,13 @@ PetscErrorCode PCView(PC pc, PetscViewer viewer)
 }
 
 /*@C
-  PCRegister -  Adds a method (`PCType`) to the preconditioner package.
+  PCRegister -  Adds a method (`PCType`) to the PETSc preconditioner package.
 
-  Not collective
+  Not collective. No Fortran Support
 
   Input Parameters:
 + sname    - name of a new user-defined solver
-- function - routine to create method context
+- function - routine to create the method context which will be stored in a `PC` when `PCSetType()` is called
 
   Example Usage:
 .vb
@@ -1885,16 +1888,23 @@ PetscErrorCode PCView(PC pc, PetscViewer viewer)
 .ve
 
   Then, your solver can be chosen with the procedural interface via
-$     PCSetType(pc, "my_solver")
+.vb
+  PCSetType(pc, "my_solver")
+.ve
   or at runtime via the option
-$     -pc_type my_solver
+.vb
+  -pc_type my_solver
+.ve
 
   Level: advanced
 
   Note:
+  A simpler alternative to using `PCRegister()` for an application specific preconditioner is to use a `PC` of `PCType` `PCSHELL` and
+  provide your customizations with `PCShellSetContext()` and `PCShellSetApply()`
+
   `PCRegister()` may be called multiple times to add several user-defined preconditioners.
 
-.seealso: [](ch_ksp), `PC`, `PCType`, `PCRegisterAll()`
+.seealso: [](ch_ksp), `PC`, `PCType`, `PCRegisterAll()`, `PCSetType()`, `PCShellSetContext()`, `PCShellSetApply()`, `PCSHELL`
 @*/
 PetscErrorCode PCRegister(const char sname[], PetscErrorCode (*function)(PC))
 {
@@ -1914,13 +1924,13 @@ static PetscErrorCode MatMult_PC(Mat A, Vec X, Vec Y)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
-  PCComputeOperator - Computes the explicit preconditioned operator.
+/*@
+  PCComputeOperator - Computes the explicit preconditioned operator as a matrix `Mat`.
 
   Collective
 
   Input Parameters:
-+ pc      - the preconditioner object
++ pc      - the `PC` preconditioner object
 - mattype - the `MatType` to be used for the operator
 
   Output Parameter:
@@ -1933,6 +1943,9 @@ static PetscErrorCode MatMult_PC(Mat A, Vec X, Vec Y)
   This routine is costly in general, and is recommended for use only with relatively small systems.
   Currently, this routine uses a dense matrix format when `mattype` == `NULL`
 
+  Developer Note:
+  This should be called `PCCreateExplicitOperator()`
+
 .seealso: [](ch_ksp), `PC`, `KSPComputeOperator()`, `MatType`
 @*/
 PetscErrorCode PCComputeOperator(PC pc, MatType mattype, Mat *mat)
@@ -1954,28 +1967,31 @@ PetscErrorCode PCComputeOperator(PC pc, MatType mattype, Mat *mat)
 }
 
 /*@
-  PCSetCoordinates - sets the coordinates of all the nodes on the local process
+  PCSetCoordinates - sets the coordinates of all the nodes (degrees of freedom in the vector) on the local process
 
   Collective
 
   Input Parameters:
-+ pc     - the solver context
++ pc     - the `PC` preconditioner context
 . dim    - the dimension of the coordinates 1, 2, or 3
 . nloc   - the blocked size of the coordinates array
 - coords - the coordinates array
 
   Level: intermediate
 
-  Note:
+  Notes:
   `coords` is an array of the dim coordinates for the nodes on
   the local processor, of size `dim`*`nloc`.
-  If there are 108 equation on a processor
-  for a displacement finite element discretization of elasticity (so
+  If there are 108 equations (dofs) on a processor
+  for a 3d displacement finite element discretization of elasticity (so
   that there are nloc = 36 = 108/3 nodes) then the array must have 108
   double precision values (ie, 3 * 36).  These x y z coordinates
   should be ordered for nodes 0 to N-1 like so: [ 0.x, 0.y, 0.z, 1.x,
   ... , N-1.z ].
 
+  The information provided here can be used by some preconditioners, such as `PCGAMG`, to produce a better preconditioner.
+  See also  `MatSetNearNullSpace()`.
+
 .seealso: [](ch_ksp), `PC`, `MatSetNearNullSpace()`
 @*/
 PetscErrorCode PCSetCoordinates(PC pc, PetscInt dim, PetscInt nloc, PetscReal coords[])
