@@ -305,12 +305,7 @@ static PetscErrorCode MatSetOption_MPIAdj(Mat A, MatOption op, PetscBool flg)
   case MAT_SPD:
     a->symmetric = flg;
     break;
-  case MAT_SYMMETRY_ETERNAL:
-  case MAT_STRUCTURAL_SYMMETRY_ETERNAL:
-  case MAT_SPD_ETERNAL:
-    break;
   default:
-    PetscCall(PetscInfo(A, "Option %s ignored\n", MatOptions[op]));
     break;
   }
   PetscFunctionReturn(PETSC_SUCCESS);
@@ -338,12 +333,6 @@ static PetscErrorCode MatGetRow_MPIAdj(Mat A, PetscInt row, PetscInt *nz, PetscI
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode MatRestoreRow_MPIAdj(Mat A, PetscInt row, PetscInt *nz, PetscInt **idx, PetscScalar **v)
-{
-  PetscFunctionBegin;
-  PetscFunctionReturn(PETSC_SUCCESS);
-}
-
 static PetscErrorCode MatEqual_MPIAdj(Mat A, Mat B, PetscBool *flg)
 {
   Mat_MPIAdj *a = (Mat_MPIAdj *)A->data, *b = (Mat_MPIAdj *)B->data;
@@ -359,7 +348,7 @@ static PetscErrorCode MatEqual_MPIAdj(Mat A, Mat B, PetscBool *flg)
   /* if a->j are the same */
   PetscCall(PetscMemcmp(a->j, b->j, (a->nz) * sizeof(PetscInt), &flag));
 
-  PetscCall(MPIU_Allreduce(&flag, flg, 1, MPIU_BOOL, MPI_LAND, PetscObjectComm((PetscObject)A)));
+  PetscCallMPI(MPIU_Allreduce(&flag, flg, 1, MPIU_BOOL, MPI_LAND, PetscObjectComm((PetscObject)A)));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
@@ -575,7 +564,7 @@ static PetscErrorCode MatAssemblyEnd_MPIAdj(Mat A, MatAssemblyType type)
 
 static struct _MatOps MatOps_Values = {MatSetValues_MPIAdj,
                                        MatGetRow_MPIAdj,
-                                       MatRestoreRow_MPIAdj,
+                                       NULL,
                                        NULL,
                                        /* 4*/ NULL,
                                        NULL,
@@ -725,6 +714,10 @@ static struct _MatOps MatOps_Values = {MatSetValues_MPIAdj,
                                        NULL,
                                        /*150*/ NULL,
                                        NULL,
+                                       NULL,
+                                       NULL,
+                                       NULL,
+                                       /*155*/ NULL,
                                        NULL};
 
 static PetscErrorCode MatMPIAdjSetPreallocation_MPIAdj(Mat B, PetscInt *i, PetscInt *j, PetscInt *values)
@@ -738,7 +731,7 @@ static PetscErrorCode MatMPIAdjSetPreallocation_MPIAdj(Mat B, PetscInt *i, Petsc
   if (values) useedgeweights = PETSC_TRUE;
   else useedgeweights = PETSC_FALSE;
   /* Make everybody knows if they are using edge weights or not */
-  PetscCall(MPIU_Allreduce((int *)&useedgeweights, (int *)&b->useedgeweights, 1, MPI_INT, MPI_MAX, PetscObjectComm((PetscObject)B)));
+  PetscCallMPI(MPIU_Allreduce((int *)&useedgeweights, (int *)&b->useedgeweights, 1, MPI_INT, MPI_MAX, PetscObjectComm((PetscObject)B)));
 
   if (PetscDefined(USE_DEBUG)) {
     PetscInt ii;
@@ -825,7 +818,7 @@ static PetscErrorCode MatMPIAdjToSeq_MPIAdj(Mat A, Mat *B)
   PetscCall(MatGetLocalSize(A, &m, NULL));
   nz = adj->nz;
   PetscCheck(adj->i[m] == nz, PETSC_COMM_SELF, PETSC_ERR_PLIB, "nz %" PetscInt_FMT " not correct i[m] %" PetscInt_FMT, nz, adj->i[m]);
-  PetscCall(MPIU_Allreduce(&nz, &NZ, 1, MPIU_INT, MPI_SUM, PetscObjectComm((PetscObject)A)));
+  PetscCallMPI(MPIU_Allreduce(&nz, &NZ, 1, MPIU_INT, MPI_SUM, PetscObjectComm((PetscObject)A)));
 
   PetscCall(PetscMPIIntCast(nz, &mnz));
   PetscCall(PetscMalloc2(size, &allnz, size, &dispnz));
@@ -872,7 +865,7 @@ static PetscErrorCode MatMPIAdjToSeqRankZero_MPIAdj(Mat A, Mat *B)
   PetscCall(MatGetLocalSize(A, &m, NULL));
   nz = adj->nz;
   PetscCheck(adj->i[m] == nz, PETSC_COMM_SELF, PETSC_ERR_PLIB, "nz %" PetscInt_FMT " not correct i[m] %" PetscInt_FMT, nz, adj->i[m]);
-  PetscCall(MPIU_Allreduce(&nz, &NZ, 1, MPIU_INT, MPI_SUM, PetscObjectComm((PetscObject)A)));
+  PetscCallMPI(MPIU_Allreduce(&nz, &NZ, 1, MPIU_INT, MPI_SUM, PetscObjectComm((PetscObject)A)));
 
   PetscCall(PetscMPIIntCast(nz, &mnz));
   if (!rank) PetscCall(PetscMalloc2(size, &allnz, size, &dispnz));
@@ -975,7 +968,7 @@ PETSC_EXTERN PetscErrorCode MatCreate_MPIAdj(Mat B)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
   MatMPIAdjToSeq - Converts an parallel `MATMPIADJ` matrix to complete `MATMPIADJ` on each process (needed by sequential partitioners)
 
   Logically Collective
@@ -997,7 +990,7 @@ PetscErrorCode MatMPIAdjToSeq(Mat A, Mat *B)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
   MatMPIAdjToSeqRankZero - Converts an parallel `MATMPIADJ` matrix to complete `MATMPIADJ` on rank zero (needed by sequential partitioners)
 
   Logically Collective
@@ -1024,7 +1017,7 @@ PetscErrorCode MatMPIAdjToSeqRankZero(Mat A, Mat *B)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
   MatMPIAdjSetPreallocation - Sets the array used for storing the matrix elements
 
   Logically Collective
@@ -1097,11 +1090,11 @@ PetscErrorCode MatMPIAdjSetPreallocation(Mat B, PetscInt *i, PetscInt *j, PetscI
   Possible values for `MatSetOption()` - `MAT_STRUCTURALLY_SYMMETRIC`
 
   Fortran Note:
-  From Fortran the indices and values are copied so the array space need not be provided with `PetscMalloc()`.
+  From Fortran the arrays `indices` and `values` must be retained by the user until `A` is destroyed
 
 .seealso: [](ch_matrices), `Mat`, `MatCreate()`, `MatConvert()`, `MatGetOrdering()`, `MATMPIADJ`, `MatMPIAdjSetPreallocation()`
 @*/
-PetscErrorCode MatCreateMPIAdj(MPI_Comm comm, PetscInt m, PetscInt N, PetscInt *i, PetscInt *j, PetscInt *values, Mat *A)
+PetscErrorCode MatCreateMPIAdj(MPI_Comm comm, PetscInt m, PetscInt N, PetscInt i[], PetscInt j[], PetscInt values[], Mat *A) PeNSS
 {
   PetscFunctionBegin;
   PetscCall(MatCreate(comm, A));
