@@ -891,7 +891,7 @@ static inline PetscErrorCode PetscTimSortBuildRunWithArray_Private(char *arr, ch
 /*@C
   PetscTimSort - Sorts an array in place in increasing order using Tim Peters <https://bugs.python.org/file4451/timsort.txt> adaptive sorting algorithm.
 
-  Not Collective
+  Not Collective, No Fortran Support
 
   Input Parameters:
 + n    - number of values
@@ -940,8 +940,8 @@ static inline PetscErrorCode PetscTimSortBuildRunWithArray_Private(char *arr, ch
 .ve
 
   Fortran Notes:
-  To use this from Fortran you must write a comparison subroutine with 4 arguments which accepts left, right, ctx and
-  returns result. For example
+  To use this from Fortran you must write a comparison subroutine with 4 arguments which accepts `left`, `right`, `ctx` and
+  returns `result`. For example
 .vb
  subroutine CompareIntegers(left,right,ctx,result)
    implicit none
@@ -1014,7 +1014,7 @@ PetscErrorCode PetscTimSort(PetscInt n, void *arr, size_t size, int (*cmp)(const
   PetscTimSortWithArray - Sorts an array in place in increasing order using Tim Peters <https://bugs.python.org/file4451/timsort.txt> adaptive sorting algorithm and
   reorders a second array to match the first. The arrays need not be the same type.
 
-  Not Collective
+  Not Collective, No Fortran Support
 
   Input Parameters:
 + n     - number of values
@@ -1066,8 +1066,8 @@ PetscErrorCode PetscTimSort(PetscInt n, void *arr, size_t size, int (*cmp)(const
 .ve
 
   Fortran Notes:
-  To use this from Fortran you must write a comparison subroutine with 4 arguments which accepts left, right, ctx and
-  returns result. For example
+  To use this from Fortran you must write a comparison subroutine with 4 arguments which accepts `left`, `right`, `ctx` and
+  returns `result`. For example
 .vb
  subroutine CompareIntegers(left,right,ctx,result)
    implicit none
