@@ -60,7 +60,7 @@ int main(int argc, char **argv)
 
   /* Initialize PETSC and TAO */
   PetscFunctionBeginUser;
-  PetscCall(PetscInitialize(&argc, &argv, (char *)0, help));
+  PetscCall(PetscInitialize(&argc, &argv, NULL, help));
 
   /* Set the default values for the problem parameters */
   user.nx     = 50;
@@ -79,7 +79,7 @@ int main(int argc, char **argv)
   PetscCall(PetscPrintf(PETSC_COMM_WORLD, "\n---- Journal Bearing Problem SHB-----\n"));
   PetscCall(PetscPrintf(PETSC_COMM_WORLD, "mx: %" PetscInt_FMT ",  my: %" PetscInt_FMT ",  ecc: %g \n\n", user.nx, user.ny, (double)user.ecc));
 
-  /* Let Petsc determine the grid division */
+  /* Let PETSc determine the grid division */
   Nx = PETSC_DECIDE;
   Ny = PETSC_DECIDE;
 
